.. include:: ../README.rst

Contents:
=========

.. toctree::
   :maxdepth: 2

   get_started
   spaik
   changelog
   authors


License Compliance Information:
===============================

.. toctree::
   :maxdepth: 1

   license_compliance
